npnlp
=====

NumPy and SciPy-based nonlinear programming and optimization.

Available Solvers
-----------------

Sequential Quadratic Programming (SQP)

Installation
------------

Using git source files

    $ git clone https://github.com/msparapa/npnlp
    $ cd npnlp
    $ pip install -e .

Using pypi

    $ pip install npnlp
